===============================
pureyaml
===============================

.. image:: https://badge.fury.io/py/pureyaml.svg
    :target: https://pypi.python.org/pypi/pureyaml/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/status/pureyaml.svg
    :target: https://pypi.python.org/pypi/pureyaml/
    :alt: Development Status

.. image:: https://travis-ci.org/bionikspoon/pureyaml.svg?branch=develop
    :target: https://travis-ci.org/bionikspoon/pureyaml?branch=develop
    :alt: Build Status

.. image:: https://coveralls.io/repos/bionikspoon/pureyaml/badge.svg?branch=develop
    :target: https://coveralls.io/github/bionikspoon/pureyaml?branch=develop&service=github
    :alt: Coverage Status

.. image:: https://readthedocs.org/projects/pureyaml/badge/?version=develop
    :target: https://pureyaml.readthedocs.org/en/develop/?badge=develop
    :alt: Documentation Status


Yet another yaml parser, in pure python.
